Struct OpBuilder

pub struct OpBuilder<'a, T: 'a> { /* private fields */ }
Type used to acquire any number of slices and make a set operation on these slices.

Implementations

Source

impl<'a, T> OpBuilder<'a, T>

pub fn new() -> Self

Construct an empty one.

pub fn with_capacity(capacity: usize) -> Self

Construct an empty one with enough space for capacity elements or more.

pub fn from_vec(slices: Vec<&'a Set<T>>) -> Self

Construct it with the content of the given slice.

Note that no other allocation than the one of the vec given in parameter is needed for the construction.

pub fn reserve(&mut self, additional: usize)

Reserve additional space for the underlying vec.

pub fn add(self, set: &'a Set<T>) -> Self

Add a new set that will be used for the future set operation and consume and return the type.

pub fn push(&mut self, set: &'a Set<T>)

Push a new set that will be used for the future set operation.

pub fn union(self) -> Union<'a, T>

Prepare the slices for the union set operation.

pub fn intersection(self) -> Intersection<'a, T>

Prepare the slices for the intersection set operation.

pub fn difference(self) -> Difference<'a, T>

Prepare the slices for the difference set operation.

pub fn symmetric_difference(self) -> SymmetricDifference<'a, T>

Prepare the slices for the symmetric difference set operation.